import { createStore } from 'vuex'
import dashboard from './dashboard/index'
import { LOGIN_SUCCESS, LOGOUT, TITLE } from './mutation-types'

const store = createStore({
    state () {
        return {
            Session: {
                Token: null,
                User: null
            },
        }
    },
    mutations: {
        initializeStore(state) {
            const store = localStorage.getItem("store");
            if(store){
                this.replaceState(
                    Object.assign(state, JSON.parse(store))
                );
            }
        },
        [TITLE](state, title) {
            document.title = "Budgeteer - " + title;
        },
        [LOGIN_SUCCESS](state, session) {
            state.Session = session;
        },
        [LOGOUT](state, token) {
            state.Session = { Token: null, User: null }
        }
    },
    modules: {
        dashboard
    }
})

store.subscribe((mutation, state) => {
    switch(mutation.type){
        case "setCurrentBudget":
            store.dispatch("fetchBudget", mutation.payload.ID)
            break;
        case "setCurrentAccount":
            store.dispatch("fetchAccount", mutation.payload.ID)
            break;
    }
})

store.subscribe((mutation, state) => {
    let persistedState = {
        Session: state.Session,
        Budgets: state.Budgets,
        CurrentBudget: state.CurrentBudget
    }
    localStorage.setItem("store", JSON.stringify(persistedState));
})

export default store